@@ -6,6 +6,7 @@ import traceback
 from django.db import connection
 from django.utils.timezone import now
 
+from .app_settings import app_settings
 
 logger = logging.getLogger(__name__)
 
@@ -26,7 +27,10 @@ class BaseLoggingMixin(object):
 
     def initial(self, request, *args, **kwargs):
         self.log = {"requested_at": now()}
-        self.log["data"] = self._clean_data(request.body)
+        if not getattr(self, "decode_request_body", app_settings.DECODE_REQUEST_BODY):
+            self.log["data"] = ""
+        else:
+            self.log["data"] = self._clean_data(request.body)
 
         super(BaseLoggingMixin, self).initial(request, *args, **kwargs)
 
@@ -57,9 +61,7 @@ class BaseLoggingMixin(object):
         )
 
         if should_log(request, response):
-            if (
-                connection.settings_dict.get("ATOMIC_REQUESTS") and getattr(response, "exception", None) and connection.in_atomic_block
-            ):
+            if (connection.settings_dict.get("ATOMIC_REQUESTS") and getattr(response, "exception", None) and connection.in_atomic_block):
                 # response with exception (HTTP status like: 401, 404, etc)
                 # pointwise disable atomic block for handle log (TransactionManagementError)
                 connection.set_rollback(True)
@@ -76,7 +78,7 @@ class BaseLoggingMixin(object):
                     "remote_addr": self._get_ip_address(request),
                     "view": self._get_view_name(request),
                     "view_method": self._get_view_method(request),
-                    "path": request.path,
+                    "path": self._get_path(request),
                     "host": request.get_host(),
                     "method": request.method,
                     "query_params": self._clean_data(request.query_params.dict()),
@@ -97,7 +99,6 @@ class BaseLoggingMixin(object):
                 # ensure that all exceptions raised by handle_log
                 # doesn't prevent API call to continue as expected
                 logger.exception("Logging API call raise exception!")
-
         return response
 
     def handle_log(self):
@@ -108,8 +109,12 @@ class BaseLoggingMixin(object):
         """
         raise NotImplementedError
 
+    def _get_path(self, request):
+        """Get the request path and truncate it"""
+        return request.path[: app_settings.PATH_LENGTH]
+
     def _get_ip_address(self, request):
-        """Get the remote ip address the request was generated from. """
+        """Get the remote ip address the request was generated from."""
         ipaddr = request.META.get("HTTP_X_FORWARDED_FOR", None)
         if ipaddr:
             ipaddr = ipaddr.split(",")[0]
@@ -147,7 +152,7 @@ class BaseLoggingMixin(object):
     def _get_view_method(self, request):
         """Get view method."""
         if hasattr(self, "action"):
-            return self.action if self.action else None
+            return self.action or None
         return request.method.lower()
 
     def _get_user(self, request):
@@ -192,6 +197,7 @@ class BaseLoggingMixin(object):
 
         if isinstance(data, list):
             return [self._clean_data(d) for d in data]
+
         if isinstance(data, dict):
             SENSITIVE_FIELDS = {
                 "api",
@@ -213,7 +219,7 @@ class BaseLoggingMixin(object):
                     value = ast.literal_eval(value)
                 except (ValueError, SyntaxError):
                     pass
-                if isinstance(value, list) or isinstance(value, dict):
+                if isinstance(value, (list, dict)):
                     data[key] = self._clean_data(value)
                 if key.lower() in SENSITIVE_FIELDS:
                     data[key] = self.CLEANED_SUBSTITUTE
